@@ -10,7 +10,7 @@
 Class providing essential data transfer operations for SFTP protocol.
 """
 
-__docformat__ = "restructuredtext en"
+__docformat__ = "google en"
 __author__ = "John Westbrook"
 __email__ = "john.westbrook@rcsb.org"
 __license__ = "Apache 2.0"
